# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/willy/book/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Willy\\Book\\": "packages/willy/book/src",
            "Willy\\Book\\Seeders\\": "packages/willy/book/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Willy\Book\Providers\BookServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Book'  => Willy\Book\Facades\Book::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Willy\\Book\\Seeders\\BookTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Willy\Book\Providers\BookServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Willy\Book\Providers\BookServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Willy\Book\Providers\BookServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/book/{modulename}

**User**

    http://path-to-route-folder/user/book/{modulename}

**Public**

    http://path-to-route-folder/books


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/book/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/book/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/book/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/book/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/book/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/book/{modulename}/{slug}
    METHOD: GET